@@ -49,7 +49,9 @@ sub acceptance_tests (%options) {
   $accepter = $accepter->new(%$accepter,
       test_dir => $accepter->test_dir->child($options{acceptance}{test_subdir}))
     if not $ENV{TEST_DIR} and $options{acceptance}{test_subdir};
-  $accepter->json_decoder->allow_bignum if Test::JSON::Schema::Acceptance->VERSION < '1.022';
+
+  $note->('Using JSON decoder: ', builtin::blessed($accepter->_json_serializer), ' ', $accepter->_json_serializer->VERSION);
+  $note->('');
 
   my $js = JSON::Schema::Modern->new($options{evaluator}->%*);
   my $js_short_circuit = $ENV{NO_SHORT_CIRCUIT} || JSON::Schema::Modern->new($options{evaluator}->%*, short_circuit => 1);
@@ -57,12 +59,6 @@ sub acceptance_tests (%options) {
   my $add_resource = sub ($uri, $schema, %resource_options) {
     return if $uri =~ m{/draft-next/};
     try {
-      # suppress warnings from parsing remotes/* intended for draft <= 7 with 'definitions'
-      local $SIG{__WARN__} = sub {
-        warn @_ if $_[0] !~ /^no-longer-supported "definitions" keyword present/;
-      } if $options{acceptance}{specification} !~ /^draft[467]$/
-          and Test::JSON::Schema::Acceptance->VERSION < '1.028';
-
       my $doc = my $document = JSON::Schema::Modern::Document->new(
         schema => $schema,
         evaluator => $js,
